@@ -58,7 +58,7 @@ typedef struct dico_key *dico_key_t;
 #define DICO_SELECT_END   2
 typedef int (*dico_select_t) (int, dico_key_t, const char *);
 
-#define DICO_MODULE_VERSION 2
+#define DICO_MODULE_VERSION 3
 
 #define DICO_CAPA_NONE 0
 #define DICO_CAPA_NODB 0x0001
@@ -68,7 +68,8 @@ struct dico_database_module {
     unsigned dico_version;
     unsigned dico_capabilities;
     int (*dico_init) (int argc, char **argv);
-    dico_handle_t (*dico_init_db) (const char *db, int argc, char **argv);
+    dico_handle_t (*dico_init_db) (const char *db, int argc, char **argv,
+				   void *extra);
     int (*dico_free_db) (dico_handle_t hp);
     int (*dico_open) (dico_handle_t hp);
     int (*dico_close) (dico_handle_t hp);
@@ -86,6 +87,7 @@ struct dico_database_module {
     void (*dico_free_result) (dico_result_t rp);
     int (*dico_result_headers) (dico_result_t rp, dico_assoc_list_t hdr);
     int (*dico_run_test) (int argc, char **argv);
+    char *(*dico_db_mime_header) (dico_handle_t hp);
 };
 
 #endif
